@@ -1,5 +1,5 @@
 /*
-    SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -7,18 +7,18 @@
 #ifndef TRANSPORTABSTRACTPLUGIN_H
 #define TRANSPORTABSTRACTPLUGIN_H
 
+#include "mailtransport_export.h"
 #include <QObject>
 #include <QVector>
-#include "mailtransport_export.h"
-namespace MailTransport {
+namespace MailTransport
+{
 class TransportJob;
 class Transport;
 /**
  * @brief The TransportAbstractPluginInfo struct
  * @author Laurent Montel <montel@kde.org>
  */
-struct MAILTRANSPORT_EXPORT TransportAbstractPluginInfo
-{
+struct MAILTRANSPORT_EXPORT TransportAbstractPluginInfo {
     QString name;
     QString identifier;
     QString description;
@@ -34,7 +34,7 @@ class MAILTRANSPORT_EXPORT TransportAbstractPlugin : public QObject
     Q_OBJECT
 public:
     explicit TransportAbstractPlugin(QObject *parent = nullptr);
-    ~TransportAbstractPlugin();
+    ~TransportAbstractPlugin() override;
 
     Q_REQUIRED_RESULT virtual TransportJob *createTransportJob(MailTransport::Transport *t, const QString &identifier) = 0;
     Q_REQUIRED_RESULT virtual QVector<TransportAbstractPluginInfo> names() const = 0;
