@@ -6,16 +6,16 @@
 
 #include "transportmgr.h"
 
+#include <QVBoxLayout>
+#include <transport.h>
+#include <transportjob.h>
 #include <transportmanager.h>
 #include <widgets/transportmanagementwidget.h>
-#include <transportjob.h>
-#include <transport.h>
-#include <QVBoxLayout>
 
-#include <QApplication>
-#include <QLineEdit>
-#include <QDebug>
 #include <KTextEdit>
+#include <QApplication>
+#include <QDebug>
+#include <QLineEdit>
 
 #include <QPushButton>
 
@@ -24,7 +24,7 @@ using namespace MailTransport;
 TransportMgr::TransportMgr()
     : mCurrentJob(nullptr)
 {
-    auto *vbox = new QVBoxLayout(this);
+    auto vbox = new QVBoxLayout(this);
     vbox->setContentsMargins(0, 0, 0, 0);
 
     vbox->addWidget(new TransportManagementWidget(this));
@@ -94,12 +94,9 @@ void TransportMgr::sendBtnClicked()
     job->setCc(mCcEdit->text().isEmpty() ? QStringList() : mCcEdit->text().split(QLatin1Char(',')));
     job->setBcc(mBccEdit->text().isEmpty() ? QStringList() : mBccEdit->text().split(QLatin1Char(',')));
     job->setData(mMailEdit->document()->toPlainText().toLatin1());
-    connect(job, &KJob::result,
-            this, &TransportMgr::jobResult);
-    connect(job, SIGNAL(percent(KJob*,ulong)),
-            SLOT(jobPercent(KJob*,ulong)));
-    connect(job, &KJob::infoMessage,
-            this, &TransportMgr::jobInfoMessage);
+    connect(job, &KJob::result, this, &TransportMgr::jobResult);
+    connect(job, SIGNAL(percent(KJob *, ulong)), SLOT(jobPercent(KJob *, ulong)));
+    connect(job, &KJob::infoMessage, this, &TransportMgr::jobInfoMessage);
     mCurrentJob = job;
     TransportManager::self()->schedule(job);
 }
@@ -117,7 +114,7 @@ int main(int argc, char **argv)
     QApplication app(argc, argv);
     app.setApplicationName(QStringLiteral("transportmgr"));
 
-    auto *t = new TransportMgr();
+    auto t = new TransportMgr();
     t->show();
     app.exec();
     delete t;
@@ -131,13 +128,13 @@ void TransportMgr::jobResult(KJob *job)
 
 void TransportMgr::jobPercent(KJob *job, unsigned long percent)
 {
-    Q_UNUSED(job);
+    Q_UNUSED(job)
     qDebug() << percent << "%";
 }
 
 void TransportMgr::jobInfoMessage(KJob *job, const QString &info, const QString &info2)
 {
-    Q_UNUSED(job);
+    Q_UNUSED(job)
     qDebug() << info;
     qDebug() << info2;
 }
