@@ -12,8 +12,12 @@
 #include <transporttype.h>
 
 class TransportPrivate;
-
-namespace MailTransport {
+namespace QKeychain
+{
+class Job;
+}
+namespace MailTransport
+{
 class TransportType;
 
 /**
@@ -92,7 +96,7 @@ public:
 
       @since 4.5
     */
-    static QString authenticationTypeString(int type);
+    static Q_REQUIRED_RESULT QString authenticationTypeString(int type);
 
     /**
       Returns a deep copy of this Transport object which will no longer be
@@ -124,7 +128,7 @@ protected:
     /**
       Returns true if the password was not stored in the wallet.
     */
-    bool needsWalletMigration() const;
+    Q_REQUIRED_RESULT bool needsWalletMigration() const;
 
     /**
       Try to migrate the password from the config file to the wallet.
@@ -137,6 +141,8 @@ private Q_SLOTS:
     void readPassword();
 
 private:
+    void readTransportPasswordFinished(QKeychain::Job *baseJob);
+    void loadPassword();
     TransportPrivate *const d;
 };
 } // namespace MailTransport
