@@ -10,7 +10,8 @@
 #include <QSharedData>
 #include <QString>
 
-namespace MailTransport {
+namespace MailTransport
+{
 /**
   @internal
 */
@@ -18,7 +19,6 @@ class TransportType::Private : public QSharedData
 {
 public:
     Private()
-        : mIsAkonadiResource(false)
     {
     }
 
@@ -34,8 +34,8 @@ public:
     QString mName;
     QString mDescription;
     QString mIdentifier;
-    bool mIsAkonadiResource;
+    bool mIsAkonadiResource = false;
 };
 } // namespace MailTransport
 
-#endif //MAILTRANSPORT_TRANSPORTTYPE_P_H
+#endif // MAILTRANSPORT_TRANSPORTTYPE_P_H
