@@ -6,9 +6,9 @@
 
 #include "attributetest.h"
 
+#include <addressattribute.h>
 #include <attributefactory.h>
 #include <qtest_akonadi.h>
-#include <addressattribute.h>
 
 #include <kmailtransportakonadi/dispatchmodeattribute.h>
 #include <kmailtransportakonadi/errorattribute.h>
@@ -73,7 +73,7 @@ void AttributeTest::testSerialization()
         cc << QStringLiteral("cc2@me.org");
         QStringList bcc(QStringLiteral("bcc1@me.org"));
         bcc << QStringLiteral("bcc2@me.org");
-        auto *a = new AddressAttribute(from, to, cc, bcc);
+        auto a = new AddressAttribute(from, to, cc, bcc);
         QByteArray data = a->serialized();
         delete a;
         a = new AddressAttribute;
@@ -92,7 +92,7 @@ void AttributeTest::testSerialization()
         qDebug() << "ms" << date.toString(QStringLiteral("z"));
         int ms = date.toString(QStringLiteral("z")).toInt();
         date = date.addMSecs(-ms);
-        auto *a = new DispatchModeAttribute(mode);
+        auto a = new DispatchModeAttribute(mode);
         a->setSendAfter(date);
         QByteArray data = a->serialized();
         delete a;
@@ -105,7 +105,7 @@ void AttributeTest::testSerialization()
 
     {
         QString msg(QStringLiteral("The #!@$ing thing failed!"));
-        auto *a = new ErrorAttribute(msg);
+        auto a = new ErrorAttribute(msg);
         QByteArray data = a->serialized();
         delete a;
         a = new ErrorAttribute;
@@ -115,7 +115,7 @@ void AttributeTest::testSerialization()
     }
 
     {
-        auto *a = new SentActionAttribute();
+        auto a = new SentActionAttribute();
         const qlonglong id = 123456789012345ll;
 
         a->addAction(SentActionAttribute::Action::MarkAsReplied, QVariant(id));
@@ -153,7 +153,7 @@ void AttributeTest::testSerialization()
         delete a;
     }
 
-    //MoveToCollection + silently
+    // MoveToCollection + silently
     {
         SentBehaviourAttribute::SentBehaviour beh = SentBehaviourAttribute::MoveToCollection;
         Collection::Id id = 123456789012345ll;
@@ -175,7 +175,7 @@ void AttributeTest::testSerialization()
         delete copy;
     }
 
-    //Delete + silently
+    // Delete + silently
     {
         SentBehaviourAttribute::SentBehaviour beh = SentBehaviourAttribute::Delete;
         Collection::Id id = 123456789012345ll;
@@ -187,19 +187,19 @@ void AttributeTest::testSerialization()
         a = new SentBehaviourAttribute;
         a->deserialize(data);
         QCOMPARE(beh, a->sentBehaviour());
-        //When delete we move to -1
+        // When delete we move to -1
         QCOMPARE(a->moveToCollection().id(), -1);
         QCOMPARE(sendSilently, a->sendSilently());
         SentBehaviourAttribute *copy = a->clone();
         QCOMPARE(copy->sentBehaviour(), beh);
-        //When delete we move to -1
+        // When delete we move to -1
         QCOMPARE(copy->moveToCollection().id(), -1);
         QCOMPARE(copy->sendSilently(), sendSilently);
         delete a;
         delete copy;
     }
 
-    //MoveToDefaultSentCollection + silently
+    // MoveToDefaultSentCollection + silently
     {
         SentBehaviourAttribute::SentBehaviour beh = SentBehaviourAttribute::MoveToDefaultSentCollection;
         Collection::Id id = 123456789012345ll;
@@ -211,12 +211,12 @@ void AttributeTest::testSerialization()
         a = new SentBehaviourAttribute;
         a->deserialize(data);
         QCOMPARE(beh, a->sentBehaviour());
-        //When movetodefaultsendCollection we move to -1
+        // When movetodefaultsendCollection we move to -1
         QCOMPARE(a->moveToCollection().id(), -1);
         QCOMPARE(sendSilently, a->sendSilently());
         SentBehaviourAttribute *copy = a->clone();
         QCOMPARE(copy->sentBehaviour(), beh);
-        //When movetodefaultsendCollection we move to -1
+        // When movetodefaultsendCollection we move to -1
         QCOMPARE(copy->moveToCollection().id(), -1);
         QCOMPARE(copy->sendSilently(), sendSilently);
         delete a;
@@ -225,7 +225,7 @@ void AttributeTest::testSerialization()
 
     {
         int id = 3219;
-        auto *a = new TransportAttribute(id);
+        auto a = new TransportAttribute(id);
         QByteArray data = a->serialized();
         delete a;
         a = new TransportAttribute;
