@@ -13,7 +13,8 @@
 
 #include <attribute.h>
 
-namespace MailTransport {
+namespace MailTransport
+{
 /**
   Attribute determining how and when a message from the outbox should be
   dispatched.  Messages can be sent immediately, sent only when the user
@@ -29,9 +30,9 @@ public:
       Determines how the message is sent.
     */
     enum DispatchMode {
-        Automatic,    ///< Send message as soon as possible, but no earlier than
+        Automatic, ///< Send message as soon as possible, but no earlier than
         ///  specified by setSendAfter()
-        Manual        ///< Send message only when the user requests so.
+        Manual ///< Send message only when the user requests so.
     };
 
     /**
@@ -46,15 +47,15 @@ public:
 
     /* reimpl */
     DispatchModeAttribute *clone() const override;
-    QByteArray type() const override;
-    QByteArray serialized() const override;
+    Q_REQUIRED_RESULT QByteArray type() const override;
+    Q_REQUIRED_RESULT QByteArray serialized() const override;
     void deserialize(const QByteArray &data) override;
 
     /**
       Returns the dispatch mode for the message.
       @see DispatchMode.
     */
-    DispatchMode dispatchMode() const;
+    Q_REQUIRED_RESULT DispatchMode dispatchMode() const;
 
     /**
       Sets the dispatch mode for the message.
@@ -67,7 +68,7 @@ public:
       Returns the date and time when the message should be sent.
       Only valid if dispatchMode() is Automatic.
     */
-    QDateTime sendAfter() const;
+    Q_REQUIRED_RESULT QDateTime sendAfter() const;
 
     /**
       Sets the date and time when the message should be sent.
