@@ -1,15 +1,15 @@
 /*
-    SPDX-FileCopyrightText: 2017-2020 Laurent Montel <montel@kde.org>
+    SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
 
     SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "akonadimailtransportplugin.h"
-#include "resourcesendjob_p.h"
 #include "mailtransportplugin_akonadi_debug.h"
-#include <KPluginFactory>
-#include <AkonadiCore/AgentManager>
+#include "resourcesendjob_p.h"
 #include <AkonadiCore/AgentInstanceCreateJob>
+#include <AkonadiCore/AgentManager>
+#include <KPluginFactory>
 #include <MailTransport/Transport>
 
 using namespace Akonadi;
@@ -65,26 +65,26 @@ QVector<MailTransport::TransportAbstractPluginInfo> AkonadiMailTransportPlugin::
 
 bool AkonadiMailTransportPlugin::configureTransport(const QString &identifier, MailTransport::Transport *transport, QWidget *parent)
 {
-    Q_UNUSED(identifier);
+    Q_UNUSED(identifier)
     AgentInstance instance = AgentManager::self()->instance(transport->host());
     if (!instance.isValid()) {
         qCWarning(MAILTRANSPORT_AKONADI_LOG) << "Invalid resource instance" << transport->host();
         return false;
     }
-    instance.configure(parent);   // Async...
+    instance.configure(parent); // Async...
     transport->save();
     return true; // No way to know here if the user cancelled or not.
 }
 
 MailTransport::TransportJob *AkonadiMailTransportPlugin::createTransportJob(MailTransport::Transport *t, const QString &identifier)
 {
-    Q_UNUSED(identifier);
+    Q_UNUSED(identifier)
     return new MailTransport::ResourceSendJob(t, this);
 }
 
 void AkonadiMailTransportPlugin::initializeTransport(MailTransport::Transport *t, const QString &identifier)
 {
-    auto *cjob = new AgentInstanceCreateJob(identifier);
+    auto cjob = new AgentInstanceCreateJob(identifier);
     if (!cjob->exec()) {
         qCWarning(MAILTRANSPORT_AKONADI_LOG) << "Failed to create agent instance of type" << identifier;
         return;
